==> haskell-optparse-simple-0.0.3-62-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.0.3
id: optparse-simple-0.0.3-HHn9vyuUG71DlTImHPVIBO
key: optparse-simple-0.0.3-HHn9vyuUG71DlTImHPVIBO
license: BSD3
copyright: 2015 FP Complete
maintainer: chrisdone@fpcomplete.com
synopsis: Simple interface to optparse-applicative
description:
    Simple interface to optparse-applicative
category: Options
author: FP Complete
exposed: True
indefinite: False
exposed-modules:
    Options.Applicative.Simple
abi: 6d5e07a6dec148a22c3add002c3c8709
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.3
library-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/optparse-simple-0.0.3
hs-libraries: HSoptparse-simple-0.0.3-HHn9vyuUG71DlTImHPVIBO
depends:
    base-4.10.0.0 template-haskell-2.12.0.0 transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU
    either-4.5-LYT0d6MLKlX83NrOtw2Pp2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=9137170527362bcbf66dd39b0705c132
             gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU=144a9a0126afbae34150c14c8b0b9fdd
             either-4.5-LYT0d6MLKlX83NrOtw2Pp2=62288d5afd316da1ac78a82ed181db6f
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-optparse-simple-0.0.4-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-optparse-simple.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: optparse-simple
version: 0.0.4
id: optparse-simple-0.0.4-9EOUtiMj6pXIAE2bfPvcjF
key: optparse-simple-0.0.4-9EOUtiMj6pXIAE2bfPvcjF
license: BSD3
copyright: 2015 FP Complete
maintainer: chrisdone@fpcomplete.com
synopsis: Simple interface to optparse-applicative
description:
    Simple interface to optparse-applicative
category: Options
author: FP Complete
exposed: True
indefinite: False
exposed-modules:
    Options.Applicative.Simple
abi: 5b49cf36db3c929ac7aec91fa7272857
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/optparse-simple-0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/optparse-simple-0.0.4
hs-libraries: HSoptparse-simple-0.0.4-9EOUtiMj6pXIAE2bfPvcjF
depends:
    base-4.10.0.0 template-haskell-2.12.0.0 transformers-0.5.2.0
    optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2
    gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU
    either-4.5-LYT0d6MLKlX83NrOtw2Pp2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             template-haskell-2.12.0.0=612ee923b47f5e11502cef08338c9f82
             transformers-0.5.2.0=9705988bf0172d3bbbcdcaf65e1d842a
             optparse-applicative-0.14.0.0-CJtbqXiElwvHJ8bj23xDw2=9137170527362bcbf66dd39b0705c132
             gitrev-1.3.1-Cgp0kQsBgtmnAoUzRW7fU=144a9a0126afbae34150c14c8b0b9fdd
             either-4.5-LYT0d6MLKlX83NrOtw2Pp2=62288d5afd316da1ac78a82ed181db6f
haddock-interfaces: /usr/share/doc/haskell-optparse-simple/html/optparse-simple.haddock
haddock-html: /usr/share/doc/haskell-optparse-simple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
